import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";
import {AdEntity} from "../types";


const defaultObject = {
    name: 'Test Name',
    description: 'blah',
    url: 'https://megak.pl',
    price:0,
    lat:9,
    lon:9,
}

afterAll(async()=>{
    await pool.end();
})

test('Adrecord returns data from database for one entry', async()=>{

    const ad = await AdRecord.getOne('abc');

    console.log(ad)

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');
    //....
})

test('AdRecord.getOne returns null from database for not existing entry', async()=>{

    const ad = await AdRecord.getOne('---');

    expect(ad).toBeNull();
})

test('AdRecord.findAll returns array of found entries', async()=>{

    const ads = await AdRecord.findAll('');

    expect(ads).not.toBe([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll returns array of found entries, when searching for "a"', async()=>{

    const ads = await AdRecord.findAll('a');

    expect(ads).not.toBe([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll returns array of found entries, when searching for that does not exist', async()=>{

    const ads = await AdRecord.findAll('-------------------------------------');

    expect(ads).toEqual([]);
})

test('AdRecord.findAll returns smaller amount of data', async()=>{

    const ads = await AdRecord.findAll('');

    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
})

test('AdRecord.insert returns new UUID', async()=>{
    /** Teraz niestety zasmiecamy naszą baze danych.
     Lepiej zrobic to za pomocą mockup-ów lub dodając jakiś prefix do name np:
     name: '[Test-231] Testowa'
     Wtedy moglibyśmy zrobić czyszczenie bazy za pomocą afterAll.
     Wyszukać dane z takim prefikcem i usunąć z bazy danych
     */
    const ad = new AdRecord(defaultObject)

    await ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
})

test('AdRecord.insert inserts data to database', async()=>{

    const ad = new AdRecord(defaultObject)
    await ad.insert()

    const  foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toEqual(ad.id);
})