"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnswerRecord = void 0;
const uuid_1 = require("uuid");
const types_1 = require("../types");
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
class AnswerRecord {
    constructor(obj) {
        this.copyBtnCount = 0;
        const { id, text, category, createdAt, modifiedAt, copyBtnCount, templateId } = obj;
        if (text.length < 3 || text.length > 3000) {
            throw new errors_1.ValidationError('Długość wpisywanego tekstu musi zawierać się w przedziale od 3 do 3000 znaków.');
        }
        if (!(category === types_1.AnswerGroupEnum.IT || category === types_1.AnswerGroupEnum.TELCO || category === types_1.AnswerGroupEnum.PREPAID || category === types_1.AnswerGroupEnum.OTHER || category === types_1.AnswerGroupEnum.MOST_COPIED)) {
            throw new errors_1.ValidationError('Nie została zaznaczona kategoria odpowiedzi.');
        }
        this.id = id;
        this.text = text;
        this.category = category;
        this.createdAt = createdAt;
        this.modifiedAt = modifiedAt;
        this.copyBtnCount = copyBtnCount;
        this.templateId = templateId;
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `answers` ORDER BY `createdAt` DESC');
            // !results.length? [] :
            return results.map(obj => new AnswerRecord(obj));
        });
    }
    static getAllSortedByCategory(category) {
        return __awaiter(this, void 0, void 0, function* () {
            if (category === types_1.AnswerGroupEnum.MOST_COPIED) {
                const [results] = yield db_1.pool.execute('SELECT * FROM `answers` ORDER BY `copyBtnCount` DESC');
                return results.map(obj => new AnswerRecord(obj));
            }
            else {
                const [results] = yield db_1.pool.execute('SELECT * FROM `answers` WHERE `category` = :category ORDER BY `createdAt` DESC', {
                    category
                });
                return results.map(obj => new AnswerRecord(obj));
            }
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `answers` WHERE `id` = :id", {
                id
            });
            return results.length === 0 ? null : new AnswerRecord(results[0]);
        });
    }
    insert() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.id = (_a = this.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
            yield db_1.pool.execute('INSERT INTO `answers`(`id`, `text`, `category`, `templateId`) VALUES(:id, :text, :category, :templateId )', {
                id: this.id,
                text: this.text,
                category: this.category,
                templateId: this.templateId,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            this.modifiedAt = new Date();
            yield db_1.pool.execute('UPDATE `answers` SET `modifiedAt` = :modifiedAt, `templateId` = :templateId, `text` =:text, `category` = :category WHERE  `id` = :id', {
                modifiedAt: this.modifiedAt,
                templateId: this.templateId,
                text: this.text,
                category: this.category,
                id: this.id,
            });
        });
    }
    updateCount() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('UPDATE `answers` SET `copyBtnCount` = `copyBtnCount` + 1 WHERE  `id` = :id', {
                id: this.id,
                copyBtnCount: this.copyBtnCount,
            });
        });
    }
    static delete(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const { affectedRows } = (yield db_1.pool.execute('DELETE FROM `answers` WHERE `id` = :id', {
                id,
            }))[0];
        });
    }
}
exports.AnswerRecord = AnswerRecord;
//# sourceMappingURL=answer.record.js.map