"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
class TemplateRecord {
    constructor(obj) {
        const { id, firstParagraph, lastParagraph, name } = obj;
        if (firstParagraph.length < 3 || firstParagraph.trim().length > 200) {
            throw new errors_1.ValidationError('Długość akapitu powitalnego  musi zawierać się w przedziale od 3 do 200 znaków.');
        }
        if (lastParagraph.trim().length < 3 || lastParagraph.trim().length > 300) {
            throw new errors_1.ValidationError('Długość akapitu końcowego  musi zawierać się w przedziale od 3 do 300 znaków.');
        }
        this.id = id;
        this.name = name;
        this.firstParagraph = firstParagraph;
        this.lastParagraph = lastParagraph;
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `templates`");
            return results.map(obj => new TemplateRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `templates` WHERE `id` = :id", {
                id
            });
            return results.length === 0 ? null : new TemplateRecord(results[0]);
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute('UPDATE `templates` SET `firstParagraph` = :firstParagraph, `lastParagraph` = :lastParagraph WHERE `id` = :id', {
                id: this.id,
                firstParagraph: this.firstParagraph,
                lastParagraph: this.lastParagraph,
            });
        });
    }
}
exports.TemplateRecord = TemplateRecord;
//# sourceMappingURL=template.record.js.map