"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.answersRouter = void 0;
const express_1 = require("express");
const answer_record_1 = require("../records/answer.record");
const template_record_1 = require("../records/template.record");
const types_1 = require("../types");
const errors_1 = require("../utils/errors");
exports.answersRouter = (0, express_1.Router)();
exports.answersRouter
    .get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const answersList = yield answer_record_1.AnswerRecord.getAll();
    const templatesList = yield template_record_1.TemplateRecord.getAll();
    res.json({
        answersList,
        templatesList,
    });
}))
    .get('/sort/:category', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { category } = req.params;
    if (!(category === types_1.AnswerGroupEnum.IT || category === types_1.AnswerGroupEnum.TELCO || category === types_1.AnswerGroupEnum.PREPAID || category === types_1.AnswerGroupEnum.OTHER || category === types_1.AnswerGroupEnum.MOST_COPIED)) {
        throw new errors_1.ValidationError('Nie została zaznaczona kategoria odpowiedzi.');
    }
    const answersList = yield answer_record_1.AnswerRecord.getAllSortedByCategory(req.params.category);
    const templatesList = yield template_record_1.TemplateRecord.getAll();
    res.json({
        answersList,
        templatesList,
    });
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const answer = yield answer_record_1.AnswerRecord.getOne(req.params.id);
    if (answer === null) {
        throw new errors_1.ValidationError('Nie można edytować odpowiedzi, która nie istnieje');
    }
    res.json({
        answer,
    });
}))
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    let answer;
    let answerId;
    if (req.body.templateId === "") {
        const answerReq = Object.assign(Object.assign({}, req.body), { templateId: null });
        answer = yield new answer_record_1.AnswerRecord(answerReq);
        answerId = yield answer.insert();
    }
    else {
        answer = yield new answer_record_1.AnswerRecord(req.body);
        answerId = yield answer.insert();
    }
    res.json({
        answer,
    });
}))
    .put('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    console.log(req.body);
    const { templateId, text, category } = req.body;
    const answer = yield answer_record_1.AnswerRecord.getOne(req.params.id);
    console.log(answer);
    if (answer === null) {
        throw new errors_1.ValidationError('Nie można edytować odpowiedzi, która nie istnieje');
    }
    if (templateId === "") {
        answer.templateId = null;
    }
    else {
        answer.templateId = templateId;
    }
    answer.text = text;
    answer.category = category;
    if (text.length < 3 || text.length > 3000) {
        throw new errors_1.ValidationError('Długość wpisywanego tekstu musi zawierać się w przedziale od 3 do 300 znaków.');
    }
    yield answer.update();
    res.json({
        answer,
    });
}))
    .put('/count/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const answer = yield answer_record_1.AnswerRecord.getOne(req.params.id);
    if (answer === null) {
        throw new errors_1.ValidationError('Nie udało się zwiększyć "copyBtnCount" w bazie danych. Rekord nie istnieje');
    }
    yield answer.updateCount();
    res.end();
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const answer = yield answer_record_1.AnswerRecord.getOne(req.params.id);
    if (answer === null) {
        throw new errors_1.ValidationError('Nie można usunąć odpowiedzi, która nie istnieje');
    }
    yield answer_record_1.AnswerRecord.delete(req.params.id);
    res.end();
}));
//# sourceMappingURL=answers.js.map