"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.templatesRouter = void 0;
const express_1 = require("express");
const template_record_1 = require("../records/template.record");
const errors_1 = require("../utils/errors");
exports.templatesRouter = (0, express_1.Router)();
exports.templatesRouter
    .get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const templatesList = yield template_record_1.TemplateRecord.getAll();
    res.json({
        templatesList,
    });
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const template = req.params.id === ""
        ? null
        : yield template_record_1.TemplateRecord.getOne(req.params.id);
    if (!template) {
        throw new errors_1.ValidationError("Nie ma szablonu o podanym ID");
    }
    res.json({
        template,
    });
}))
    .put('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const template = yield template_record_1.TemplateRecord.getOne(req.params.id);
    if (template === null) {
        throw new errors_1.ValidationError('Nie znaleziono szablonu o podanym ID');
    }
    if (template.firstParagraph === req.body.firstParagraph && template.lastParagraph === req.body.lastParagraph) {
        throw new errors_1.ValidationError('Nie dokonałeś żadnych zmian w szablonie, modyfikacja nie została wysłana na serwer');
    }
    template.firstParagraph = req.body.firstParagraph;
    template.lastParagraph = req.body.lastParagraph;
    if (template.firstParagraph.length < 3 || template.firstParagraph.trim().length > 200) {
        throw new errors_1.ValidationError('Długość akapitu powitalnego  musi zawierać się w przedziale od 3 do 200 znaków.');
    }
    if (template.lastParagraph.trim().length < 3 || template.lastParagraph.trim().length > 300) {
        throw new errors_1.ValidationError('Długość akapitu końcowego  musi zawierać się w przedziale od 3 do 300 znaków.');
    }
    yield template.update();
    res.json({
        template,
    });
}));
//# sourceMappingURL=templates.js.map