"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../utils/db");
const answer_record_1 = require("../records/answer.record");
const defaultObject = {
    text: '[Test from JEST], testowa odpowiedź',
    category: 'it',
    templateId: 'f7a9eba4-9704-11ec-b0c8-309c23e04364',
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('testing asynchronous code', () => __awaiter(void 0, void 0, void 0, function* () {
    const answers = yield answer_record_1.AnswerRecord.getAll();
    expect(answers).toBeDefined();
}));
test('AnswerRecord.getOne returns data from database for one entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const answer = yield answer_record_1.AnswerRecord.getOne('51841ce4-36e2-465a-b091-0b83c6c47997');
    expect(answer).toBeDefined();
    expect(answer.id).toBe('51841ce4-36e2-465a-b091-0b83c6c47997');
    expect(answer.category).toBe('telco');
    expect(answer.templateId).toBe('f7a9eba4-9704-11ec-b0c8-309c23e04364');
}));
test('AnswerRecord.getOne returns null from database for not existing entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const answer = yield answer_record_1.AnswerRecord.getOne('---');
    expect(answer).toBeNull();
}));
test('AnswerRecord.getAll returns array of found entries', () => __awaiter(void 0, void 0, void 0, function* () {
    const answers = yield answer_record_1.AnswerRecord.getAll();
    expect(answers).not.toBe([]);
    expect(answers[0].id).toBeDefined();
}));
test('AnswerRecord.insert returns new UUID', () => __awaiter(void 0, void 0, void 0, function* () {
    const answer = new answer_record_1.AnswerRecord({
        category: "other",
        templateId: "f7a9eba4-9704-11ec-b0c8-309c23e04364",
        text: "[Test from JEST], testowa odpowiedź"
    });
    yield answer.insert();
    expect(answer.id).toBeDefined();
    expect(typeof answer.id).toBe('string');
    expect(answer.id).toMatch(/^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/);
}));
test('AnswerRecord.insert inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const answer = new answer_record_1.AnswerRecord({
        category: "it",
        templateId: "f7a9eba4-9704-11ec-b0c8-309c23e04364",
        text: "[Test from JEST], testowa odpowiedź nr 2"
    });
    yield answer.insert();
    const foundAnswer = yield answer_record_1.AnswerRecord.getOne(answer.id);
    expect(foundAnswer).toBeDefined();
    expect(foundAnswer).not.toBeNull();
    expect(foundAnswer.id).toEqual(answer.id);
}));
test('Validates invalid length of text', () => {
    expect(() => new answer_record_1.AnswerRecord(Object.assign(Object.assign({}, defaultObject), { text: '' }))).toThrow('Długość wpisywanego tekstu musi zawierać się w przedziale od 3 do 3000 znaków.');
});
test('Validates invalid category', () => {
    expect(() => new answer_record_1.AnswerRecord(Object.assign(Object.assign({}, defaultObject), { category: '' }))).toThrow('Nie została zaznaczona kategoria odpowiedzi.');
});
test('Validates templateId, convert "" to null ', () => __awaiter(void 0, void 0, void 0, function* () {
    const answer = new answer_record_1.AnswerRecord(Object.assign(Object.assign({}, defaultObject), { templateId: null }));
    const id = yield answer.insert();
    const foundAnswer = yield answer_record_1.AnswerRecord.getOne(id);
    expect(foundAnswer.templateId).toBeNull();
}));
//# sourceMappingURL=answer.test.js.map